==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/bibtexfileexporter.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILEEXPORTER_H
#define BIBTEXFILEEXPORTER_H

#include <qobject.h>

class QWaitCondition;
class QProcess;
class QIODevice;

class BibTeXFile;

class BibTeXFileExporter: public QObject
{
    Q_OBJECT

public:
    BibTeXFileExporter( BibTeXFile *bibTeXFile );
    ~BibTeXFileExporter();

    bool save( QIODevice *iodevice, BibTeXFile::Format format = BibTeXFile::formatBibTeX, BibTeXFile::Encoding encoding = BibTeXFile::encImplicit );

signals:
    void progress( int current, int total );

public slots:
    void cancel();

private:
    BibTeXFile *file;
    QWaitCondition *wc;
    QProcess *process;

    bool exportAsPS( const QDir& tempDir, QIODevice *iodevice );
    bool exportAsPDF( const QDir& tempDir, QIODevice *iodevice );

    bool writeLatexFile( const QString &filename );
    bool runProcess( const QDir& tempDir, const QStringList &args );
    bool runProcesses( const QDir& tempDir, const QStringList &commandLines );

    QString createTempDir();
    void deleteTempDir( const QString& directory );

private slots:
    void slotProcessExited();
    void slotReadProcessOutput();

};


#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexporter.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXFILEEXPORTER_H
#define BIBTEXBIBTEXFILEEXPORTER_H

#include <qobject.h>

class QIODevice;

namespace BibTeX
{
    class BibTeXFile;
    class BibTeXElement;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporter : public QObject
    {
        Q_OBJECT
    public:
        BibTeXFileExporter();
        ~BibTeXFileExporter();

        virtual bool save( QIODevice *iodevice, BibTeXFile *bibtexfile ) = 0;
        virtual bool save( QIODevice *iodevice, BibTeXElement* element ) = 0;

    signals:
        void progress( int current, int total );

    public slots:
        virtual void cancel()
        {
            // nothing
        };
    };

}

#endif
